#!/usr/bin/env python3
# -*- coding:utf-8 -*-
"""
@File  : helloworld.py
@Author: HappyLay
@Date  : 2020/10/15 13:33
@Desc  : 安徽理工大学
"""
__author__ = 'HappyLay'


def hi():
    """
    向世界的第一个问候(*^▽^*)
    :return: None
    """
    print("hello world , 2020🇨🇳加油，世界ヾ(◍°∇°◍)ﾉﾞ。")
    return None
